@@ -34,8 +34,6 @@
 #include "seahorse-servers.h"
 #include "seahorse-util.h"
 
-#include <gnome-keyring.h>
-
 #include <glib/gi18n.h>
 
 #include <string.h>
@@ -150,11 +148,11 @@ seahorse_pgp_backend_constructed (GObject *obj)
 	self->unknown = seahorse_unknown_source_new ();
 
 #ifdef WITH_KEYSERVER
-	g_signal_connect (seahorse_context_pgp_settings (NULL), "changed::keyservers",
+	g_signal_connect (seahorse_application_pgp_settings (NULL), "changed::keyservers",
 	                  G_CALLBACK (on_settings_keyservers_changed), self);
 
 	/* Initial loading */
-	on_settings_keyservers_changed (seahorse_context_pgp_settings (NULL), "keyservers", self);
+	on_settings_keyservers_changed (seahorse_application_pgp_settings (NULL), "keyservers", self);
 #endif
 }
 
@@ -191,7 +189,7 @@ seahorse_pgp_backend_finalize (GObject *obj)
 	SeahorsePgpBackend *self = SEAHORSE_PGP_BACKEND (obj);
 
 #ifdef WITH_KEYSERVER
-	g_signal_handlers_disconnect_by_func (seahorse_context_pgp_settings (NULL),
+	g_signal_handlers_disconnect_by_func (seahorse_application_pgp_settings (NULL),
 	                                      on_settings_keyservers_changed, self);
 #endif
 
@@ -306,7 +304,7 @@ seahorse_pgp_backend_get_default_key (SeahorsePgpBackend *self)
 	self = self ? self : seahorse_pgp_backend_get ();
 	g_return_val_if_fail (SEAHORSE_IS_PGP_BACKEND (self), NULL);
 
-	settings = seahorse_context_pgp_settings (NULL);
+	settings = seahorse_application_pgp_settings (NULL);
 	if (settings != NULL) {
 		value = g_settings_get_string (settings, "default-key");
 		if (value != NULL && value[0]) {
@@ -426,7 +424,7 @@ seahorse_pgp_backend_search_remote_async (SeahorsePgpBackend *self,
 	g_return_if_fail (SEAHORSE_IS_PGP_BACKEND (self));
 
 	/* Get a list of all selected key servers */
-	names = g_settings_get_strv (seahorse_context_settings (NULL), "last-search-servers");
+	names = g_settings_get_strv (seahorse_application_settings (NULL), "last-search-servers");
 	if (names != NULL && names[0] != NULL) {
 		servers = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 		for (i = 0; names[i] != NULL; i++)
@@ -701,20 +699,20 @@ seahorse_pgp_backend_discover_keys (SeahorsePgpBackend *self,
 		robjects = g_list_prepend (robjects, key);
 	}
 
-	g_ptr_array_add (todiscover, NULL);
+	if (todiscover->len > 0) {
+		g_ptr_array_add (todiscover, NULL);
+		keyids = (const gchar **)todiscover->pdata;
 
-	/* Start a discover process on all todiscover */
-	if (todiscover != NULL &&
-	    g_settings_get_boolean (seahorse_context_settings (NULL), "server-auto-retrieve")) {
-		seahorse_pgp_backend_retrieve_async (self, (const gchar **)todiscover->pdata,
-		                                     SEAHORSE_PLACE (self->keyring),
-		                                     cancellable, NULL, NULL);
-	}
+		/* Start a discover process on all todiscover */
+		if (g_settings_get_boolean (seahorse_application_settings (NULL), "server-auto-retrieve"))
+			seahorse_pgp_backend_retrieve_async (self, keyids, SEAHORSE_PLACE (self->keyring),
+			                                     cancellable, NULL, NULL);
 
-	/* Add unknown objects for all these */
-	for (i = 0; keyids[i] != NULL; i++) {
-		object = seahorse_unknown_source_add_object (self->unknown, keyids[i], cancellable);
-		robjects = g_list_prepend (robjects, object);
+		/* Add unknown objects for all these */
+		for (i = 0; keyids[i] != NULL; i++) {
+			object = seahorse_unknown_source_add_object (self->unknown, keyids[i], cancellable);
+			robjects = g_list_prepend (robjects, object);
+		}
 	}
 
 	g_ptr_array_free (todiscover, TRUE);
