@@ -24,7 +24,14 @@
 
 #include <glib.h>
 
-#define SEAHORSE_PKCS11_TYPE_STR "pkcs11"
-#define SEAHORSE_PKCS11_TYPE g_quark_from_string ("pkcs11")
+#include <gcr/gcr.h>
+
+#define SEAHORSE_PKCS11_NAME "pkcs11"
+
+#ifdef WITH_PKCS11
+
+void       seahorse_pkcs11_backend_initialize    (void);
+
+#endif /* WITH_PKCS11 */
 
 #endif
